pub enum QueryMsg {
List {
start_after: Option<String>,
limit: Option<u32>,
},
GetTotal {
swap_type: SwapType,
},
GetOffers {
page: Option<u32>,
limit: Option<u32>,
},
GetListings {
page: Option<u32>,
limit: Option<u32>,
},
ListingsOfToken {
token_id: String,
swap_type: Option<SwapType>,
page: Option<u32>,
limit: Option<u32>,
},
SwapsOf {
address: Addr,
swap_type: Option<SwapType>,
page: Option<u32>,
limit: Option<u32>,
},
SwapsByPrice {
min: Option<Uint128>,
max: Option<Uint128>,
swap_type: Option<SwapType>,
page: Option<u32>,
limit: Option<u32>,
},
SwapsByDenom {
payment_token: Option<Addr>,
swap_type: Option<SwapType>,
page: Option<u32>,
limit: Option<u32>,
},
SwapsByPaymentType {
cw20: bool,
swap_type: Option<SwapType>,
page: Option<u32>,
limit: Option<u32>,
},
Details {
id: String,
},
}Variants
List
Get all swaps (enumerable) Return type: ListResponse
GetTotal
GetOffers
Get all swaps of type SwapType::Offer
GetListings
Get all swaps of type SwapType::Sale
ListingsOfToken
Get all listings for a token of type Swap::Sale and Swap::Offer
or both (None)
SwapsOf
Show all swaps created by a specific address
Defaults to SwapType::Sale if no swap_type
SwapsByPrice
Show all swaps of a given price range
Fields
SwapsByDenom
Show all swaps of a given denom (contract address) Defaults to ARCH if no contract is sent
SwapsByPaymentType
Show all cw20 swaps, or all ARCH swaps
Details
Returns the details of the named swap, error if not created. Return type: DetailsResponse.